==> 1.9.1.zip: jack2/macosx/JackMachSemaphore.h <==
/*
Copyright (C) 2004-2008 Grame

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU Lesser General Public License as published by
the Free Software Foundation; either version 2.1 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public License
along with this program; if not, write to the Free Software 
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.

*/

#ifndef __JackMachSemaphore__
#define __JackMachSemaphore__

#include "JackCompilerDeps.h"
#include "JackSynchro.h"
#include <mach/mach.h>
#include <mach/mach_types.h>
#include <mach/message.h>
#include <mach/mach_error.h>
#include <servers/bootstrap.h>
#include <mach/semaphore.h>

namespace Jack
{

/*!
\brief Inter process synchronization using using Mach semaphore.
*/

class SERVER_EXPORT JackMachSemaphore : public detail::JackSynchro
{

    private:

        semaphore_t fSemaphore;
        static mach_port_t fBootPort;

    protected:

        void BuildName(const char* name, const char* server_name, char* res);

    public:

        JackMachSemaphore(): fSemaphore(0)
        {}

        bool Signal();
        bool SignalAll();
        bool Wait();
        bool TimedWait(long usec);

        bool Allocate(const char* name, const char* server_name, int value);
        bool Connect(const char* name, const char* server_name);
        bool ConnectInput(const char* name, const char* server_name);
        bool ConnectOutput(const char* name, const char* server_name);
        bool Disconnect();
        void Destroy();
};


} // end of namespace


#endif

==> v1.9.18.zip: jack2/macosx/JackMachSemaphore.h <==
/*
Copyright (C) 2004-2008 Grame

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU Lesser General Public License as published by
the Free Software Foundation; either version 2.1 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.

*/

#ifndef __JackMachSemaphore__
#define __JackMachSemaphore__

#include "JackCompilerDeps.h"
#include "JackSynchro.h"
#include <mach/mach.h>
#include <servers/bootstrap.h>
#include <mach/semaphore.h>

namespace Jack
{

/*!
\brief Inter process synchronization using using Mach semaphore.
*/

class SERVER_EXPORT JackMachSemaphore : public detail::JackSynchro
{

    private:

        semaphore_t fSemaphore;
        mach_port_t fBootPort;

        int fSharedMem;
        char* fSharedName;

        bool recursiveBootstrapRegister(int counter);

    protected:

        void BuildName(const char* name, const char* server_name, char* res, int size);

    public:

        JackMachSemaphore():JackSynchro(), fSemaphore(0), fBootPort(0), fSharedMem(0), fSharedName(NULL)
        {}

        bool Signal();
        bool SignalAll();
        bool Wait();
        bool TimedWait(long usec);

        bool Allocate(const char* name, const char* server_name, int value);
        bool Connect(const char* name, const char* server_name);
        bool ConnectInput(const char* name, const char* server_name);
        bool ConnectOutput(const char* name, const char* server_name);
        bool Disconnect();
        void Destroy();
};


} // end of namespace


#endif
